==> zio-aws-databrew_3-5.17.128.1-sources.jar: zio/aws/databrew/model/CreateProfileJobRequest.scala <==
package zio.aws.databrew.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databrew.model.primitives.{
  Timeout,
  TagValue,
  Arn,
  DatasetName,
  JobName,
  EncryptionKeyArn,
  MaxCapacity,
  MaxRetries,
  TagKey
}
import scala.jdk.CollectionConverters.*
final case class CreateProfileJobRequest(
    datasetName: DatasetName,
    encryptionKeyArn: Option[EncryptionKeyArn] = None,
    encryptionMode: Option[zio.aws.databrew.model.EncryptionMode] = None,
    name: JobName,
    logSubscription: Option[zio.aws.databrew.model.LogSubscription] = None,
    maxCapacity: Option[MaxCapacity] = None,
    maxRetries: Option[MaxRetries] = None,
    outputLocation: zio.aws.databrew.model.S3Location,
    configuration: Option[zio.aws.databrew.model.ProfileConfiguration] = None,
    validationConfigurations: Option[
      Iterable[zio.aws.databrew.model.ValidationConfiguration]
    ] = None,
    roleArn: Arn,
    tags: Option[Map[TagKey, TagValue]] = None,
    timeout: Option[Timeout] = None,
    jobSample: Option[zio.aws.databrew.model.JobSample] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest = {
    import CreateProfileJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
      .builder()
      .datasetName(DatasetName.unwrap(datasetName): java.lang.String)
      .optionallyWith(
        encryptionKeyArn.map(value =>
          EncryptionKeyArn.unwrap(value): java.lang.String
        )
      )(_.encryptionKeyArn)
      .optionallyWith(encryptionMode.map(value => value.unwrap))(
        _.encryptionMode
      )
      .name(JobName.unwrap(name): java.lang.String)
      .optionallyWith(logSubscription.map(value => value.unwrap))(
        _.logSubscription
      )
      .optionallyWith(
        maxCapacity.map(value => MaxCapacity.unwrap(value): Integer)
      )(_.maxCapacity)
      .optionallyWith(
        maxRetries.map(value => MaxRetries.unwrap(value): Integer)
      )(_.maxRetries)
      .outputLocation(outputLocation.buildAwsValue())
      .optionallyWith(configuration.map(value => value.buildAwsValue()))(
        _.configuration
      )
      .optionallyWith(
        validationConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.validationConfigurations)
      .roleArn(Arn.unwrap(roleArn): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(timeout.map(value => Timeout.unwrap(value): Integer))(
        _.timeout
      )
      .optionallyWith(jobSample.map(value => value.buildAwsValue()))(
        _.jobSample
      )
      .build()
  }
  def asReadOnly: zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly =
    zio.aws.databrew.model.CreateProfileJobRequest.wrap(buildAwsValue())
}
object CreateProfileJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databrew.model.CreateProfileJobRequest =
      zio.aws.databrew.model.CreateProfileJobRequest(
        datasetName,
        encryptionKeyArn.map(value => value),
        encryptionMode.map(value => value),
        name,
        logSubscription.map(value => value),
        maxCapacity.map(value => value),
        maxRetries.map(value => value),
        outputLocation.asEditable,
        configuration.map(value => value.asEditable),
        validationConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        roleArn,
        tags.map(value => value),
        timeout.map(value => value),
        jobSample.map(value => value.asEditable)
      )
    def datasetName: DatasetName
    def encryptionKeyArn: Option[EncryptionKeyArn]
    def encryptionMode: Option[zio.aws.databrew.model.EncryptionMode]
    def name: JobName
    def logSubscription: Option[zio.aws.databrew.model.LogSubscription]
    def maxCapacity: Option[MaxCapacity]
    def maxRetries: Option[MaxRetries]
    def outputLocation: zio.aws.databrew.model.S3Location.ReadOnly
    def configuration
        : Option[zio.aws.databrew.model.ProfileConfiguration.ReadOnly]
    def validationConfigurations
        : Option[List[zio.aws.databrew.model.ValidationConfiguration.ReadOnly]]
    def roleArn: Arn
    def tags: Option[Map[TagKey, TagValue]]
    def timeout: Option[Timeout]
    def jobSample: Option[zio.aws.databrew.model.JobSample.ReadOnly]
    def getDatasetName: ZIO[Any, Nothing, DatasetName] =
      ZIO.succeed(datasetName)
    def getEncryptionKeyArn: ZIO[Any, AwsError, EncryptionKeyArn] =
      AwsError.unwrapOptionField("encryptionKeyArn", encryptionKeyArn)
    def getEncryptionMode
        : ZIO[Any, AwsError, zio.aws.databrew.model.EncryptionMode] =
      AwsError.unwrapOptionField("encryptionMode", encryptionMode)
    def getName: ZIO[Any, Nothing, JobName] = ZIO.succeed(name)
    def getLogSubscription
        : ZIO[Any, AwsError, zio.aws.databrew.model.LogSubscription] =
      AwsError.unwrapOptionField("logSubscription", logSubscription)
    def getMaxCapacity: ZIO[Any, AwsError, MaxCapacity] =
      AwsError.unwrapOptionField("maxCapacity", maxCapacity)
    def getMaxRetries: ZIO[Any, AwsError, MaxRetries] =
      AwsError.unwrapOptionField("maxRetries", maxRetries)
    def getOutputLocation
        : ZIO[Any, Nothing, zio.aws.databrew.model.S3Location.ReadOnly] =
      ZIO.succeed(outputLocation)
    def getConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.databrew.model.ProfileConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("configuration", configuration)
    def getValidationConfigurations: ZIO[Any, AwsError, List[
      zio.aws.databrew.model.ValidationConfiguration.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "validationConfigurations",
      validationConfigurations
    )
    def getRoleArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(roleArn)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
    def getTimeout: ZIO[Any, AwsError, Timeout] =
      AwsError.unwrapOptionField("timeout", timeout)
    def getJobSample
        : ZIO[Any, AwsError, zio.aws.databrew.model.JobSample.ReadOnly] =
      AwsError.unwrapOptionField("jobSample", jobSample)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ) extends zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly {
    override val datasetName: DatasetName =
      zio.aws.databrew.model.primitives.DatasetName(impl.datasetName())
    override val encryptionKeyArn: Option[EncryptionKeyArn] = scala
      .Option(impl.encryptionKeyArn())
      .map(value => zio.aws.databrew.model.primitives.EncryptionKeyArn(value))
    override val encryptionMode: Option[zio.aws.databrew.model.EncryptionMode] =
      scala
        .Option(impl.encryptionMode())
        .map(value => zio.aws.databrew.model.EncryptionMode.wrap(value))
    override val name: JobName =
      zio.aws.databrew.model.primitives.JobName(impl.name())
    override val logSubscription
        : Option[zio.aws.databrew.model.LogSubscription] = scala
      .Option(impl.logSubscription())
      .map(value => zio.aws.databrew.model.LogSubscription.wrap(value))
    override val maxCapacity: Option[MaxCapacity] = scala
      .Option(impl.maxCapacity())
      .map(value => zio.aws.databrew.model.primitives.MaxCapacity(value))
    override val maxRetries: Option[MaxRetries] = scala
      .Option(impl.maxRetries())
      .map(value => zio.aws.databrew.model.primitives.MaxRetries(value))
    override val outputLocation: zio.aws.databrew.model.S3Location.ReadOnly =
      zio.aws.databrew.model.S3Location.wrap(impl.outputLocation())
    override val configuration
        : Option[zio.aws.databrew.model.ProfileConfiguration.ReadOnly] = scala
      .Option(impl.configuration())
      .map(value => zio.aws.databrew.model.ProfileConfiguration.wrap(value))
    override val validationConfigurations: Option[
      List[zio.aws.databrew.model.ValidationConfiguration.ReadOnly]
    ] = scala
      .Option(impl.validationConfigurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.databrew.model.ValidationConfiguration.wrap(item)
        }.toList
      )
    override val roleArn: Arn =
      zio.aws.databrew.model.primitives.Arn(impl.roleArn())
    override val tags: Option[Map[TagKey, TagValue]] = scala
      .Option(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.databrew.model.primitives
              .TagKey(key) -> zio.aws.databrew.model.primitives.TagValue(value)
          })
          .toMap
      )
    override val timeout: Option[Timeout] = scala
      .Option(impl.timeout())
      .map(value => zio.aws.databrew.model.primitives.Timeout(value))
    override val jobSample: Option[zio.aws.databrew.model.JobSample.ReadOnly] =
      scala
        .Option(impl.jobSample())
        .map(value => zio.aws.databrew.model.JobSample.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ): zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-databrew_3-5.17.295.22-sources.jar: zio/aws/databrew/model/CreateProfileJobRequest.scala <==
package zio.aws.databrew.model
import zio.aws.databrew.model.primitives.{
  Timeout,
  TagValue,
  Arn,
  DatasetName,
  JobName,
  EncryptionKeyArn,
  MaxCapacity,
  MaxRetries,
  TagKey
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class CreateProfileJobRequest(
    datasetName: DatasetName,
    encryptionKeyArn: Optional[EncryptionKeyArn] = Optional.Absent,
    encryptionMode: Optional[zio.aws.databrew.model.EncryptionMode] =
      Optional.Absent,
    name: JobName,
    logSubscription: Optional[zio.aws.databrew.model.LogSubscription] =
      Optional.Absent,
    maxCapacity: Optional[MaxCapacity] = Optional.Absent,
    maxRetries: Optional[MaxRetries] = Optional.Absent,
    outputLocation: zio.aws.databrew.model.S3Location,
    configuration: Optional[zio.aws.databrew.model.ProfileConfiguration] =
      Optional.Absent,
    validationConfigurations: Optional[
      Iterable[zio.aws.databrew.model.ValidationConfiguration]
    ] = Optional.Absent,
    roleArn: Arn,
    tags: Optional[Map[TagKey, TagValue]] = Optional.Absent,
    timeout: Optional[Timeout] = Optional.Absent,
    jobSample: Optional[zio.aws.databrew.model.JobSample] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest = {
    import CreateProfileJobRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
      .builder()
      .datasetName(DatasetName.unwrap(datasetName): java.lang.String)
      .optionallyWith(
        encryptionKeyArn.map(value =>
          EncryptionKeyArn.unwrap(value): java.lang.String
        )
      )(_.encryptionKeyArn)
      .optionallyWith(encryptionMode.map(value => value.unwrap))(
        _.encryptionMode
      )
      .name(JobName.unwrap(name): java.lang.String)
      .optionallyWith(logSubscription.map(value => value.unwrap))(
        _.logSubscription
      )
      .optionallyWith(
        maxCapacity.map(value => MaxCapacity.unwrap(value): Integer)
      )(_.maxCapacity)
      .optionallyWith(
        maxRetries.map(value => MaxRetries.unwrap(value): Integer)
      )(_.maxRetries)
      .outputLocation(outputLocation.buildAwsValue())
      .optionallyWith(configuration.map(value => value.buildAwsValue()))(
        _.configuration
      )
      .optionallyWith(
        validationConfigurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.validationConfigurations)
      .roleArn(Arn.unwrap(roleArn): java.lang.String)
      .optionallyWith(
        tags.map(value =>
          value
            .map({ case (key, value) =>
              (TagKey.unwrap(key): java.lang.String) -> (TagValue.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.tags)
      .optionallyWith(timeout.map(value => Timeout.unwrap(value): Integer))(
        _.timeout
      )
      .optionallyWith(jobSample.map(value => value.buildAwsValue()))(
        _.jobSample
      )
      .build()
  }
  def asReadOnly: zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly =
    zio.aws.databrew.model.CreateProfileJobRequest.wrap(buildAwsValue())
}
object CreateProfileJobRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databrew.model.CreateProfileJobRequest =
      zio.aws.databrew.model.CreateProfileJobRequest(
        datasetName,
        encryptionKeyArn.map(value => value),
        encryptionMode.map(value => value),
        name,
        logSubscription.map(value => value),
        maxCapacity.map(value => value),
        maxRetries.map(value => value),
        outputLocation.asEditable,
        configuration.map(value => value.asEditable),
        validationConfigurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        roleArn,
        tags.map(value => value),
        timeout.map(value => value),
        jobSample.map(value => value.asEditable)
      )
    def datasetName: DatasetName
    def encryptionKeyArn: Optional[EncryptionKeyArn]
    def encryptionMode: Optional[zio.aws.databrew.model.EncryptionMode]
    def name: JobName
    def logSubscription: Optional[zio.aws.databrew.model.LogSubscription]
    def maxCapacity: Optional[MaxCapacity]
    def maxRetries: Optional[MaxRetries]
    def outputLocation: zio.aws.databrew.model.S3Location.ReadOnly
    def configuration
        : Optional[zio.aws.databrew.model.ProfileConfiguration.ReadOnly]
    def validationConfigurations: Optional[
      List[zio.aws.databrew.model.ValidationConfiguration.ReadOnly]
    ]
    def roleArn: Arn
    def tags: Optional[Map[TagKey, TagValue]]
    def timeout: Optional[Timeout]
    def jobSample: Optional[zio.aws.databrew.model.JobSample.ReadOnly]
    def getDatasetName: ZIO[Any, Nothing, DatasetName] =
      ZIO.succeed(datasetName)
    def getEncryptionKeyArn: ZIO[Any, AwsError, EncryptionKeyArn] =
      AwsError.unwrapOptionField("encryptionKeyArn", encryptionKeyArn)
    def getEncryptionMode
        : ZIO[Any, AwsError, zio.aws.databrew.model.EncryptionMode] =
      AwsError.unwrapOptionField("encryptionMode", encryptionMode)
    def getName: ZIO[Any, Nothing, JobName] = ZIO.succeed(name)
    def getLogSubscription
        : ZIO[Any, AwsError, zio.aws.databrew.model.LogSubscription] =
      AwsError.unwrapOptionField("logSubscription", logSubscription)
    def getMaxCapacity: ZIO[Any, AwsError, MaxCapacity] =
      AwsError.unwrapOptionField("maxCapacity", maxCapacity)
    def getMaxRetries: ZIO[Any, AwsError, MaxRetries] =
      AwsError.unwrapOptionField("maxRetries", maxRetries)
    def getOutputLocation
        : ZIO[Any, Nothing, zio.aws.databrew.model.S3Location.ReadOnly] =
      ZIO.succeed(outputLocation)
    def getConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.databrew.model.ProfileConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField("configuration", configuration)
    def getValidationConfigurations: ZIO[Any, AwsError, List[
      zio.aws.databrew.model.ValidationConfiguration.ReadOnly
    ]] = AwsError.unwrapOptionField(
      "validationConfigurations",
      validationConfigurations
    )
    def getRoleArn: ZIO[Any, Nothing, Arn] = ZIO.succeed(roleArn)
    def getTags: ZIO[Any, AwsError, Map[TagKey, TagValue]] =
      AwsError.unwrapOptionField("tags", tags)
    def getTimeout: ZIO[Any, AwsError, Timeout] =
      AwsError.unwrapOptionField("timeout", timeout)
    def getJobSample
        : ZIO[Any, AwsError, zio.aws.databrew.model.JobSample.ReadOnly] =
      AwsError.unwrapOptionField("jobSample", jobSample)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ) extends zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly {
    override val datasetName: DatasetName =
      zio.aws.databrew.model.primitives.DatasetName(impl.datasetName())
    override val encryptionKeyArn: Optional[EncryptionKeyArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionKeyArn())
        .map(value => zio.aws.databrew.model.primitives.EncryptionKeyArn(value))
    override val encryptionMode
        : Optional[zio.aws.databrew.model.EncryptionMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.encryptionMode())
        .map(value => zio.aws.databrew.model.EncryptionMode.wrap(value))
    override val name: JobName =
      zio.aws.databrew.model.primitives.JobName(impl.name())
    override val logSubscription
        : Optional[zio.aws.databrew.model.LogSubscription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.logSubscription())
        .map(value => zio.aws.databrew.model.LogSubscription.wrap(value))
    override val maxCapacity: Optional[MaxCapacity] = zio.aws.core.internal
      .optionalFromNullable(impl.maxCapacity())
      .map(value => zio.aws.databrew.model.primitives.MaxCapacity(value))
    override val maxRetries: Optional[MaxRetries] = zio.aws.core.internal
      .optionalFromNullable(impl.maxRetries())
      .map(value => zio.aws.databrew.model.primitives.MaxRetries(value))
    override val outputLocation: zio.aws.databrew.model.S3Location.ReadOnly =
      zio.aws.databrew.model.S3Location.wrap(impl.outputLocation())
    override val configuration
        : Optional[zio.aws.databrew.model.ProfileConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configuration())
        .map(value => zio.aws.databrew.model.ProfileConfiguration.wrap(value))
    override val validationConfigurations: Optional[
      List[zio.aws.databrew.model.ValidationConfiguration.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.validationConfigurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.databrew.model.ValidationConfiguration.wrap(item)
        }.toList
      )
    override val roleArn: Arn =
      zio.aws.databrew.model.primitives.Arn(impl.roleArn())
    override val tags: Optional[Map[TagKey, TagValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.tags())
      .map(value =>
        value.asScala
          .map({ case (key, value) =>
            zio.aws.databrew.model.primitives
              .TagKey(key) -> zio.aws.databrew.model.primitives.TagValue(value)
          })
          .toMap
      )
    override val timeout: Optional[Timeout] = zio.aws.core.internal
      .optionalFromNullable(impl.timeout())
      .map(value => zio.aws.databrew.model.primitives.Timeout(value))
    override val jobSample
        : Optional[zio.aws.databrew.model.JobSample.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.jobSample())
        .map(value => zio.aws.databrew.model.JobSample.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databrew.model.CreateProfileJobRequest
  ): zio.aws.databrew.model.CreateProfileJobRequest.ReadOnly = new Wrapper(impl)
}
